body{background-color:initial!important;border:none!important;margin:0;overflow:hidden;padding:0}.chat-container{align-items:center;-webkit-backdrop-filter:blur(10px);backdrop-filter:blur(10px);background:#ffffff1a;border:none;border-radius:30px;bottom:10px;box-shadow:2px 3px 5px #0003;display:flex;justify-content:space-between;left:50%;max-width:1000px;padding:10px;position:fixed;transform:translateX(-50%);width:90%;z-index:1000}.chat-input{-webkit-backdrop-filter:blur(6px);backdrop-filter:blur(6px);background:#fff3;border:none;border-radius:20px;box-shadow:inset 0 4px 10px #0000001a;color:#000;flex-grow:2;font-size:16px;line-height:1.4;margin-right:10px;min-height:40px;outline:none;overflow:hidden;padding:10px;resize:none;transition:height .2s ease}.chat-input::placeholder{color:#000000b3}.icon-btn{align-items:center;background:linear-gradient(145deg,#00b0f0,#00d4ff);border:none;border-radius:50%;box-shadow:0 4px 15px #0003;color:#fff;cursor:pointer;display:flex;font-size:20px;height:50px;justify-content:center;outline:none;transition:background-color .3s,transform .3s,box-shadow .3s;width:50px}.icon-btn:hover{background:linear-gradient(145deg,#ff66b2,#eb0451);box-shadow:0 8px 20px #ff66b266}.icon-btn:active{transform:scale(1.1)}.icon-btn:focus{border:none;outline:none}[data-testid=stBottomBlockContainer] .chat-container{-webkit-backdrop-filter:blur(12px);backdrop-filter:blur(12px);background:#ffffff1a;border-radius:30px;bottom:0!important;box-shadow:0 8px 32px #0003;left:0!important;margin:0 auto!important;padding:10px 20px!important;position:fixed!important;right:0!important;z-index:1000!important}@media (max-width:768px){.chat-container{max-width:90%;padding:8px}.chat-input{font-size:14px}.icon-btn{font-size:18px;height:45px;width:45px}}@media (max-width:480px){.chat-container{max-width:100%;padding:5px}.chat-input{font-size:12px}.icon-btn{font-size:16px;height:40px;width:40px}}
/*# sourceMappingURL=main.8d240626.css.map*/